searchNodes=[{"doc":"IP lookup, with longest prefix match, for IPv4, IPv6 prefixes (and others). Iptrie manages multiple Radix trees, one for each type of Pfx.t/0 prefix used as determined by their maxlen property. That way, IPv4 prefixes ( maxlen: 32 ) use a different radix tree as opposed to e.g. IPv6 ( maxlen: 128 ). Iptrie has a bias towards IPv4 and IPv6 since it uses Pfx to convert arguments to a Pfx.t/0 struct. So, doing other types of prefixes will require the actual Pfx.t/0 structs as arguments for the various Iptrie functions. Like Pfx , Iptrie tries to mirror the representation of results to the argument(s) given. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.2.3.0/24&quot; , &quot;v4&quot; ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , &quot;T.N.T&quot; ) ...&gt; |&gt; put ( &quot;0.0.0.0/0&quot; , &quot;v4 default&quot; ) ...&gt; |&gt; put ( &quot;::/0&quot; , &quot;no dynamite&quot; ) ...&gt; |&gt; put ( % Pfx { bits : &lt;&lt; 0xaa , 0xbb , 0xcc , 0xdd &gt;&gt; , maxlen : 48 } , &quot;some OUI&quot; ) iex&gt; iex&gt; lookup ( ipt , &quot;1.2.3.128&quot; ) { &quot;1.2.3.0/24&quot; , &quot;v4&quot; } iex&gt; iex&gt; # mirror digits representation iex&gt; iex&gt; lookup ( ipt , { 1 , 2 , 3 , 128 } ) iex&gt; { { { 1 , 2 , 3 , 0 } , 24 } , &quot;v4&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;10.11.12.13&quot; ) { &quot;0.0.0.0/0&quot; , &quot;v4 default&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;acdc:1975::&quot; ) { &quot;acdc:1975:0:0:0:0:0:0/32&quot; , &quot;T.N.T&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;abba::&quot; ) { &quot;0:0:0:0:0:0:0:0/0&quot; , &quot;no dynamite&quot; } iex&gt; iex&gt; # use %Pfx{}, since Iptrie only converts IPv4 / IPv6 representations iex&gt; iex&gt; lookup ( ipt , % Pfx { bits : &lt;&lt; 0xaa , 0xbb , 0xcc , 0xdd , 0xee &gt;&gt; , maxlen : 48 } ) { % Pfx { bits : &lt;&lt; 0xAA , 0xBB , 0xCC , 0xDD &gt;&gt; , maxlen : 48 } , &quot;some OUI&quot; } iex&gt; iex&gt; # uses three separate radix trees: iex&gt; iex&gt; Map . get ( ipt , 32 ) { 0 , { 7 , [ { &quot;&quot; , &quot;v4 default&quot; } ] , [ { &lt;&lt; 1 , 2 , 3 &gt;&gt; , &quot;v4&quot; } ] } , nil } iex&gt; iex&gt; Map . get ( ipt , 128 ) { 0 , [ { &quot;&quot; , &quot;no dynamite&quot; } ] , [ { &lt;&lt; 172 , 220 , 25 , 117 &gt;&gt; , &quot;T.N.T&quot; } ] } iex&gt; iex&gt; Map . get ( ipt , 48 ) { 0 , nil , [ { &lt;&lt; 170 , 187 , 204 , 221 &gt;&gt; , &quot;some OUI&quot; } ] }","ref":"Iptrie.html","title":"Iptrie","type":"module"},{"doc":"Delete one or more prefix, value-pair(s) from the trie using an exact match. The list of prefixes to delete may contains all types , so all sorts of prefixes can be deleted from multiple radix trees in one go. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , &quot;one&quot; ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , &quot;two&quot; ) iex&gt; iex&gt; lookup ( ipt , &quot;1.1.1.1&quot; ) { &quot;1.1.1.0/24&quot; , &quot;one&quot; } iex&gt; iex&gt; Map . get ( ipt , 32 ) |&gt; Radix . keys ( ) [ &lt;&lt; 1 , 1 , 1 &gt;&gt; , &lt;&lt; 2 , 2 , 2 &gt;&gt; ] iex&gt; iex&gt; ipt = delete ( ipt , &quot;1.1.1.0/24&quot; ) iex&gt; iex&gt; lookup ( ipt , &quot;1.1.1.1&quot; ) nil iex&gt; iex&gt; Map . get ( ipt , 32 ) |&gt; Radix . keys ( ) [ &lt;&lt; 2 , 2 , 2 &gt;&gt; ] iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , &quot;one&quot; ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , &quot;two&quot; ) ...&gt; |&gt; put ( &quot;abba:1973::/32&quot; , &quot;Ring Ring&quot; ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , &quot;T.N.T&quot; ) iex&gt; iex&gt; ipt = delete ( ipt , [ &quot;1.1.1.0/24&quot; , &quot;abba:1973::/32&quot; ] ) iex&gt; iex&gt; Map . get ( ipt , 32 ) |&gt; Radix . keys ( ) [ &lt;&lt; 2 , 2 , 2 &gt;&gt; ] iex&gt; iex&gt; Map . get ( ipt , 128 ) |&gt; Radix . keys ( ) [ &lt;&lt; 0xacdc :: 16 , 0x1975 :: 16 &gt;&gt; ]","ref":"Iptrie.html#delete/2","title":"Iptrie.delete/2","type":"function"},{"doc":"Return one or more prefix,value-pair(s) using an exact match for given prefix(es) . Examples iex&gt; ipt = new ( [ { &quot;1.1.1.0/30&quot; , &quot;A&quot; } , { &quot;1.1.1.0/31&quot; , &quot;B&quot; } , { &quot;1.1.1.0&quot; , &quot;C&quot; } ] ) iex&gt; iex&gt; get ( ipt , &quot;1.1.1.0/31&quot; ) { &quot;1.1.1.0/31&quot; , &quot;B&quot; } iex&gt; iex&gt; # or get a list of entries iex&gt; iex&gt; get ( ipt , [ &quot;1.1.1.0/30&quot; , &quot;1.1.1.0&quot; ] ) [ { &quot;1.1.1.0/30&quot; , &quot;A&quot; } , { &quot;1.1.1.0&quot; , &quot;C&quot; } ]","ref":"Iptrie.html#get/2","title":"Iptrie.get/2","type":"function"},{"doc":"Return all the prefixes for all available radix trees in trie . Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 1 ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , 2 ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , 3 ) ...&gt; |&gt; put ( &quot;acdc:2021::/32&quot; , 4 ) iex&gt; iex&gt; keys ( ipt ) ...&gt; |&gt; Enum . map ( fn x -&gt; &quot; \#{ x } &quot; end ) [ &quot;1.1.1.0/24&quot; , &quot;2.2.2.0/24&quot; , &quot;acdc:1975:0:0:0:0:0:0/32&quot; , &quot;acdc:2021:0:0:0:0:0:0/32&quot; ]","ref":"Iptrie.html#keys/1","title":"Iptrie.keys/1","type":"function"},{"doc":"Return the prefixes from the radix tree(s) in trie for given type . Where type is a single maxlen or a list thereof. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 1 ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , 2 ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , 3 ) ...&gt; |&gt; put ( &quot;acdc:2021::/32&quot; , 4 ) iex&gt; iex&gt; keys ( ipt , 32 ) [ % Pfx { bits : &lt;&lt; 1 , 1 , 1 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 2 , 2 , 2 &gt;&gt; , maxlen : 32 } ] iex&gt; iex&gt; keys ( ipt , 128 ) [ % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1975 :: 16 &gt;&gt; , maxlen : 128 } , % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x2021 :: 16 &gt;&gt; , maxlen : 128 } ] iex&gt; iex&gt; keys ( ipt , 48 ) [ ] iex&gt; iex&gt; keys ( ipt , [ 32 , 48 , 128 ] ) [ % Pfx { bits : &lt;&lt; 1 , 1 , 1 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 2 , 2 , 2 &gt;&gt; , maxlen : 32 } , % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x1975 :: 16 &gt;&gt; , maxlen : 128 } , % Pfx { bits : &lt;&lt; 0xacdc :: 16 , 0x2021 :: 16 &gt;&gt; , maxlen : 128 } ]","ref":"Iptrie.html#keys/2","title":"Iptrie.keys/2","type":"function"},{"doc":"Return all the prefix,value-pairs whose prefix is a prefix for the given search prefix . This returns the less specific entries that enclose the given search prefix . Note that any bitstring is always a prefix of itself. So, if present, the search key will be included in the result. If prefix is not present or not valid, or cannot be encoded as an Ipv4 op IPv6 Pfx.t/0 , an empty list is returned. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/25&quot; , &quot;A25-lower&quot; ) ...&gt; |&gt; put ( &quot;1.1.1.128/25&quot; , &quot;A25-upper&quot; ) ...&gt; |&gt; put ( &quot;1.1.1.0/30&quot; , &quot;A30&quot; ) ...&gt; |&gt; put ( &quot;1.1.2.0/24&quot; , &quot;B24&quot; ) iex&gt; iex&gt; less ( ipt , &quot;1.1.1.0/30&quot; ) [ { &quot;1.1.1.0/30&quot; , &quot;A30&quot; } , { &quot;1.1.1.0/25&quot; , &quot;A25-lower&quot; } , ] iex&gt; less ( ipt , &quot;2.2.2.2&quot; ) [ ]","ref":"Iptrie.html#less/2","title":"Iptrie.less/2","type":"function"},{"doc":"Return the prefix,value-pair, whose prefix is the longest match for given search prefix . Returns nil if there is no match for search prefix . Silently ignores any errors when encoding the given search prefix by returning nil. Example","ref":"Iptrie.html#lookup/2","title":"Iptrie.lookup/2","type":"function"},{"doc":"Return all the prefix,value-pairs where the search prefix is a prefix for the stored prefix. This returns the more specific entries that are enclosed by given search prefix . Note that any bitstring is always a prefix of itself. So, if present, the search prefix will be included in the result. If prefix is not valid, or cannot be encoded as an Ipv4 op IPv6 t:Pfx.t , nil is returned. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/25&quot; , &quot;A25-lower&quot; ) ...&gt; |&gt; put ( &quot;1.1.1.128/25&quot; , &quot;A25-upper&quot; ) ...&gt; |&gt; put ( &quot;1.1.1.0/30&quot; , &quot;A30&quot; ) ...&gt; |&gt; put ( &quot;1.1.2.0/24&quot; , &quot;B24&quot; ) iex&gt; iex&gt; more ( ipt , &quot;1.1.1.0/24&quot; ) [ { &quot;1.1.1.0/30&quot; , &quot;A30&quot; } , { &quot;1.1.1.0/25&quot; , &quot;A25-lower&quot; } , { &quot;1.1.1.128/25&quot; , &quot;A25-upper&quot; } ]","ref":"Iptrie.html#more/2","title":"Iptrie.more/2","type":"function"},{"doc":"Create an new, empty Iptrie. Example iex&gt; Iptrie . new ( ) % Iptrie { }","ref":"Iptrie.html#new/0","title":"Iptrie.new/0","type":"function"},{"doc":"Create a new Iptrie, populated via a list of { prefix/0 , any/0 }-pairs. Example iex&gt; ipt = Iptrie . new ( [ { &quot;1.1.1.0/24&quot; , &quot;net1&quot; } , { &quot;acdc:1975::/32&quot; , &quot;TNT&quot; } ] ) iex&gt; Map . get ( ipt , 32 ) { 0 , [ { &lt;&lt; 1 , 1 , 1 &gt;&gt; , &quot;net1&quot; } ] , nil } iex&gt; Map . get ( ipt , 128 ) { 0 , nil , [ { &lt;&lt; 172 , 220 , 25 , 117 &gt;&gt; , &quot;TNT&quot; } ] }","ref":"Iptrie.html#new/1","title":"Iptrie.new/1","type":"function"},{"doc":"Populate the trie with a list of {prefix,value}-pairs. This always uses an exact match for prefix , updating its value if it exists. Any errors are silently ignored as the trie is always returned. Example iex&gt; ipt = new ( [ { &quot;1.1.1.0/24&quot; , 0 } , { &quot;1.1.1.1&quot; , 0 } , { &quot;1.1.1.1&quot; , &quot;x&quot; } ] ) iex&gt; iex&gt; get ( ipt , &quot;1.1.1.1&quot; ) { &quot;1.1.1.1&quot; , &quot;x&quot; }","ref":"Iptrie.html#put/2","title":"Iptrie.put/2","type":"function"},{"doc":"Puts value under prefix in the trie . This always uses an exact match for prefix , replacing its value if it exists. Any errors are silently ignored as the tree is always returned. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 0 ) ...&gt; |&gt; put ( &quot;1.1.1.1&quot; , 1 ) ...&gt; |&gt; put ( &quot;1.1.1.1&quot; , &quot;x&quot; ) iex&gt; iex&gt; get ( ipt , &quot;1.1.1.1&quot; ) { &quot;1.1.1.1&quot; , &quot;x&quot; }","ref":"Iptrie.html#put/3","title":"Iptrie.put/3","type":"function"},{"doc":"Lookup prefix and update the matched entry, only if found. Uses longest prefix match, so search prefix is usually matched by some less specific prefix. If matched, fun is called on its value. If prefix had no longest prefix match, the trie is returned unchanged. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 0 ) ...&gt; |&gt; update ( &quot;1.1.1.0&quot; , fn x -&gt; x + 1 end ) ...&gt; |&gt; update ( &quot;1.1.1.1&quot; , fn x -&gt; x + 1 end ) ...&gt; |&gt; update ( &quot;2.2.2.2&quot; , fn x -&gt; x + 1 end ) iex&gt; get ( ipt , &quot;1.1.1.0/24&quot; ) { &quot;1.1.1.0/24&quot; , 2 } iex&gt; lookup ( ipt , &quot;2.2.2.2&quot; ) nil","ref":"Iptrie.html#update/3","title":"Iptrie.update/3","type":"function"},{"doc":"Lookup prefix and, if found, update its value or insert the default. Uses longest prefix match, so search prefix is usually matched by some less specific prefix. If matched, fun is called on the entry's value. If prefix had no longest prefix match, the default is inserted and fun is not called. Example iex&gt; ipt = new ( ) ...&gt; |&gt; update ( &quot;1.1.1.0/24&quot; , 0 , fn x -&gt; x + 1 end ) ...&gt; |&gt; update ( &quot;1.1.1.0&quot; , 0 , fn x -&gt; x + 1 end ) ...&gt; |&gt; update ( &quot;1.1.1.1&quot; , 0 , fn x -&gt; x + 1 end ) iex&gt; lookup ( ipt , &quot;1.1.1.2&quot; ) { &quot;1.1.1.0/24&quot; , 2 }","ref":"Iptrie.html#update/4","title":"Iptrie.update/4","type":"function"},{"doc":"Return all the values stored in all radix trees in trie . Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 1 ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , 2 ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , 3 ) ...&gt; |&gt; put ( &quot;acdc:2021::/32&quot; , 4 ) iex&gt; iex&gt; values ( ipt ) [ 1 , 2 , 3 , 4 ]","ref":"Iptrie.html#values/1","title":"Iptrie.values/1","type":"function"},{"doc":"Return the values stored in the radix trees in trie for given type . Where type is a either single maxlen or a list thereof. Example iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.1.1.0/24&quot; , 1 ) ...&gt; |&gt; put ( &quot;2.2.2.0/24&quot; , 2 ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , 3 ) ...&gt; |&gt; put ( &quot;acdc:2021::/32&quot; , 4 ) iex&gt; iex&gt; values ( ipt , 32 ) [ 1 , 2 ] iex&gt; iex&gt; values ( ipt , 128 ) [ 3 , 4 ] iex&gt; iex&gt; values ( ipt , 48 ) [ ] iex&gt; iex&gt; values ( ipt , [ 32 , 48 , 128 ] ) [ 1 , 2 , 3 , 4 ]","ref":"Iptrie.html#values/2","title":"Iptrie.values/2","type":"function"},{"doc":"A prefix represented as an opague Pfx.t/0 struct, an Pfx.ip_address/0 , Pfx.ip_prefix/0 or CIDR string. See: Pfx .","ref":"Iptrie.html#t:prefix/0","title":"Iptrie.prefix/0","type":"type"},{"doc":"An Iptrie struct that contains a Radix tree per type of Pfx.t/0 used. A prefix' type is determined by its maxlen property: IPv4 has maxlen: 32 , IPv6 has maxlen: 128 , MAC addresses have maxlen: 48 and so on. Although Iptrie facilitates lpm lookups of any type of prefix, it has a bias towards IP prefixes. So, any binaries (strings) are interpreted as CIDR-strings and tuples of address digits and/or {address-digits, length) are interpreted as IPv4 or IPv6 representations.","ref":"Iptrie.html#t:t/0","title":"Iptrie.t/0","type":"type"},{"doc":"README Online Documentation . IP lookup, with longest prefix match, for IPv4, IPv6 prefixes (and others). Iptrie manages multiple Radix trees, one for each type of Pfx.t/0 prefix used as determined by their maxlen property. That way, IPv4 prefixes ( maxlen: 32 ) use a different radix tree as opposed to e.g. IPv6 ( maxlen: 128 ). Iptrie has a bias towards IPv4 and IPv6 since it uses Pfx to convert arguments to a Pfx.t/0 struct. So, doing other types of prefixes will require the actual Pfx.t/0 structs as arguments for the various Iptrie functions. Like Pfx , Iptrie tries to mirror the representation of results to the argument(s) given.","ref":"readme.html","title":"README","type":"extras"},{"doc":"iex&gt; ipt = new ( ) ...&gt; |&gt; put ( &quot;1.2.3.0/24&quot; , &quot;v4&quot; ) ...&gt; |&gt; put ( &quot;acdc:1975::/32&quot; , &quot;T.N.T&quot; ) ...&gt; |&gt; put ( &quot;0.0.0.0/0&quot; , &quot;v4 default&quot; ) ...&gt; |&gt; put ( &quot;::/0&quot; , &quot;no dynamite&quot; ) ...&gt; |&gt; put ( % Pfx { bits : &lt;&lt; 0xaa , 0xbb , 0xcc , 0xdd &gt;&gt; , maxlen : 48 } , &quot;some OUI&quot; ) iex&gt; iex&gt; lookup ( ipt , &quot;1.2.3.128&quot; ) { &quot;1.2.3.0/24&quot; , &quot;v4&quot; } iex&gt; iex&gt; # mirror digits representation iex&gt; iex&gt; lookup ( ipt , { 1 , 2 , 3 , 128 } ) iex&gt; { { { 1 , 2 , 3 , 0 } , 24 } , &quot;v4&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;10.11.12.13&quot; ) { &quot;0.0.0.0/0&quot; , &quot;v4 default&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;acdc:1975::&quot; ) { &quot;acdc:1975:0:0:0:0:0:0/32&quot; , &quot;T.N.T&quot; } iex&gt; iex&gt; lookup ( ipt , &quot;abba::&quot; ) { &quot;0:0:0:0:0:0:0:0/0&quot; , &quot;no dynamite&quot; } iex&gt; iex&gt; # use %Pfx{}, since Iptrie only converts IPv4 / IPv6 representations iex&gt; iex&gt; lookup ( ipt , % Pfx { bits : &lt;&lt; 0xaa , 0xbb , 0xcc , 0xdd , 0xee &gt;&gt; , maxlen : 48 } ) { % Pfx { bits : &lt;&lt; 0xAA , 0xBB , 0xCC , 0xDD &gt;&gt; , maxlen : 48 } , &quot;some OUI&quot; } iex&gt; iex&gt; # uses three separate radix trees: iex&gt; iex&gt; Map . get ( ipt , 32 ) { 0 , { 7 , [ { &quot;&quot; , &quot;v4 default&quot; } ] , [ { &lt;&lt; 1 , 2 , 3 &gt;&gt; , &quot;v4&quot; } ] } , nil } iex&gt; iex&gt; Map . get ( ipt , 128 ) { 0 , [ { &quot;&quot; , &quot;no dynamite&quot; } ] , [ { &lt;&lt; 172 , 220 , 25 , 117 &gt;&gt; , &quot;T.N.T&quot; } ] } iex&gt; iex&gt; Map . get ( ipt , 48 ) { 0 , nil , [ { &lt;&lt; 170 , 187 , 204 , 221 &gt;&gt; , &quot;some OUI&quot; } ] }","ref":"readme.html#example","title":"README - Example","type":"extras"},{"doc":"Iptrie can be installed by adding iptrie to your list of dependencies in mix.exs : def deps do [ { :iptrie , &quot;~&gt; 0.1.0&quot; } ] end Repositiory is on github .","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"Changelog 0.1.0 initial version","ref":"changelog.html","title":"Changelog","type":"extras"}]